@@ -276,6 +276,12 @@ public:
 public:
 
     // bind an interface of type IF to this port
+#if defined(__clang__) || \
+   (defined(__GNUC__) && ((__GNUC__ * 1000 + __GNUC_MINOR__) >= 4006))
+// ignore warning about deliberately hidden "bind()" overloads
+#pragma GCC diagnostic push
+#pragma GCC diagnostic ignored "-Woverloaded-virtual"
+#endif
 
     virtual void bind( IF& interface_ )
 	{ base_type::bind( interface_ ); }
@@ -283,7 +289,6 @@ public:
     void operator () ( IF& interface_ )
 	{ this->bind( interface_ ); }
 
-
     // bind a parent port with type IF to this port
 
     virtual void bind( port_type& parent_ )
@@ -292,6 +297,11 @@ public:
     void operator () ( port_type& parent_ )
 	{ this->bind( parent_ ); }
 
+#if defined(__clang__) || \
+   (defined(__GNUC__) && ((__GNUC__ * 1000 + __GNUC_MINOR__) >= 4006))
+#pragma GCC diagnostic pop
+#endif
+
 
     // number of connected interfaces
 
