@@ -701,11 +701,6 @@ public:
         return sc_unsigned_proxy().to_string( numrep, w_prefix );
     }
 
-#if defined(SC_BIGINT_CONFIG_TEMPLATE_CLASS_HAS_NO_BASE_CLASS)
-public: // "mirror" for sc_value_base concatenation support:
-  int              concat_length(bool xzp) const    { return W; }
-#endif // SC_BIGINT_CONFIG_TEMPLATE_CLASS_HAS_NO_BASE_CLASS
-
 public: // field and template value accesses:
 
   inline int              get_actual_length() const { return W+1; }
