@@ -512,6 +512,8 @@ sc_biguint<W>::operator>>=(int v)
   return *this;
 }
 
+// sc_bv<W> and sc_lv<W> constructors and assignments using an sc_biguint<WO> value:
+
 template<int W>
 template<int WO>
 sc_bv<W>::sc_bv( const sc_biguint<WO>& v )
@@ -528,6 +530,20 @@ sc_lv<W>::sc_lv( const sc_biguint<WO>& v )
     *this = v.sc_unsigned_proxy();
 }
 
+template<int W>
+template<int WO>
+sc_bv<W>& sc_bv<W>::operator = ( const sc_biguint<WO>& v )
+{
+    return *this = v.sc_unsigned_proxy();
+}
+
+template<int W>
+template<int WO>
+sc_lv<W>& sc_lv<W>::operator = ( const sc_biguint<WO>& v )
+{
+    return *this = v.sc_unsigned_proxy();
+}
+
 
 } // namespace sc_dt
 
