@@ -67,7 +67,6 @@
 #define SC_UINT_BASE_H
 
 
-#include "sysc/kernel/sc_object.h"
 #include "sysc/datatypes/misc/sc_value_base.h"
 #include "sysc/datatypes/int/sc_int_ids.h"
 #include "sysc/datatypes/int/sc_length_param.h"
@@ -826,7 +825,7 @@ public:
 	{ return (uint64) m_val; }
 
     double to_double() const
-        { return uint64_to_double( m_val ); }
+        { return static_cast<double>( m_val ); }
 
 
     long long_low() const
