@@ -34,6 +34,7 @@
 #include "sysc/kernel/sc_cor_fiber.h"
 #include "sysc/kernel/sc_cor_pthread.h"
 #include "sysc/kernel/sc_cor_qt.h"
+#include "sysc/kernel/sc_cor_std_thread.h"
 #include "sysc/kernel/sc_event.h"
 #include "sysc/kernel/sc_kernel_ids.h"
 #include "sysc/kernel/sc_module.h"
@@ -339,7 +340,6 @@ sc_simcontext::init()
     m_collectable = new sc_process_list;
     m_time_params = new sc_time_params;
     m_curr_time = SC_ZERO_TIME;
-    m_max_time = SC_ZERO_TIME;
     m_change_stamp = 0;
     m_delta_count = 0;
     m_initial_delta_count_at_current_time = 0;
@@ -406,8 +406,8 @@ sc_simcontext::sc_simcontext() :
     m_write_check(SC_SIGNAL_WRITE_CHECK_DEFAULT_), m_next_proc_id(-1),
     m_child_events(), m_child_objects(), m_delta_events(), m_timed_events(0),
     m_trace_files(), m_something_to_trace(false), m_runnable(0), m_collectable(0),
-    m_time_params(), m_curr_time(SC_ZERO_TIME), m_max_time(SC_ZERO_TIME),
-    m_change_stamp(0), m_delta_count(0), m_initial_delta_count_at_current_time(0),
+    m_time_params(), m_change_stamp(0),
+    m_delta_count(0), m_initial_delta_count_at_current_time(0),
     m_forced_stop(false), m_paused(false),
     m_ready_to_simulate(false), m_elaboration_done(false),
     m_execution_phase(phase_initialize), m_error(0),
@@ -877,7 +877,7 @@ sc_simcontext::simulate( const sc_time& duration )
 	return;
     }
 
-    sc_time non_overflow_time = max_time() - m_curr_time;
+    sc_time non_overflow_time = sc_time::max() - m_curr_time;
     if ( duration > non_overflow_time )
     {
         SC_REPORT_ERROR(SC_ID_SIMULATION_TIME_OVERFLOW_, "");
@@ -1640,7 +1640,7 @@ SC_API sc_time sc_time_to_pending_activity( const sc_simcontext* simc_p )
     // If there is an activity pending at the current time
     // return a delta of zero.
 
-    sc_time result=SC_ZERO_TIME; // time of pending activity.
+    sc_time result; // time of pending activity.
 
     if ( simc_p->pending_activity_at_current_time() )
     {
@@ -1651,7 +1651,7 @@ SC_API sc_time sc_time_to_pending_activity( const sc_simcontext* simc_p )
 
     else
     {
-        result = simc_p->max_time();
+        result = sc_time::max();
         simc_p->next_time(result);
         result -= sc_time_stamp();
     }
@@ -1757,7 +1757,7 @@ sc_start( const sc_time& duration, sc_starvation_policy p )
 SC_API void
 sc_start()
 {
-    sc_start( sc_max_time() - sc_time_stamp(),
+    sc_start( sc_time::max() - sc_time_stamp(),
               SC_EXIT_ON_STARVATION );
 }
 
@@ -1812,12 +1812,6 @@ SC_API sc_object* sc_find_object( const char* name )
 }
 
 
-SC_API const sc_time&
-sc_max_time()
-{
-    return sc_get_curr_simcontext()->max_time();
-}
-
 SC_API const sc_time&
 sc_time_stamp()
 {
