@@ -19,7 +19,7 @@
 
 /*****************************************************************************
 
-  5.16.7.cpp -- Test code snipped from IEEE Std 1666-2023 LRM 
+  6.30.6.cpp -- Test code snipped from IEEE Std 1666-2023 LRM 
 
   Original Author: Andy Goodrich, Accellera Systems Initiative
 
@@ -27,60 +27,34 @@
 
 #include <systemc>
 
-void scan_hierarchy( sc_core::sc_object* obj ) {
-    std::vector<sc_core::sc_object*> children = obj->get_child_objects();
-    std::cout << "object " << obj->name() << std::endl;
-    for ( size_t i = 0; i < children.size(); ++i ) {
-        if ( children[i] ) {
-	    scan_hierarchy(children[i]);
-	}
-    }
-}
 
-void snoop()
-{
-    std::vector<sc_core::sc_object*> tops = sc_core::sc_get_top_level_objects();
-    for ( size_t i = 0; i < tops.size(); ++i ) {
-        if ( tops[i] ) {
-	    scan_hierarchy(tops[i]);
-	}
+SC_MODULE(Mod) {
+    sc_core::sc_event_queue EQ;
+
+    SC_CTOR(Mod) {
+        SC_THREAD(T);
+	SC_METHOD(M);
+	sensitive << EQ;
+	dont_initialize();
     }
 
-    sc_core::sc_object* obj = sc_core::sc_find_object("foo.foobar");
-    if ( obj ) {
-        std::cout << obj->name() << std::endl;
+    void T() {
+        EQ.notify(2.0, sc_core::SC_NS);
+        EQ.notify(1.0, sc_core::SC_NS);
+	EQ.notify(sc_core::SC_ZERO_TIME);
+        EQ.notify(1.0, sc_core::SC_NS);
     }
 
-    sc_core::sc_module* m;
-    if ( (m = dynamic_cast<sc_core::sc_module*>(obj)) ) {
-        std::cout << obj->name() << " is an sc_module" << std::endl;
+    void M() {
+        std::cout << sc_core::sc_time_stamp() << std::endl;
     }
-
-    sc_core::sc_object* parent = obj->get_parent_object();
-    if ( parent ) {
-        std::cout << "parent of " << obj->name() << " is " << parent->name() 
-	          << " " << parent->kind() << std::endl;
-    }
-}
-
-
-SC_MODULE(Bottom) {
-    sc_core::sc_signal<int> SC_NAMED(sig1), SC_NAMED(sig2);
-
-    SC_CTOR(Bottom) {}
-};
-
-SC_MODULE(Top) {
-    Bottom fb;
-    SC_CTOR(Top) : fb("foobar") {}
 };
 
 int sc_main( int argc, char* argv[] ) { 
 
-    Top top("foo");
-
-    snoop();
+    Mod m("m");
 
+    sc_core::sc_start();
     std::cout << "program completed" << std::endl;
     return 0;
 }
